==> genometools_1.5.1.orig.tar.gz: genometools-1.5.1/src/extended/extract_feature_visitor.h <==
/*
  Copyright (c) 2006-2011 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef EXTRACT_FEATURE_VISITOR_H
#define EXTRACT_FEATURE_VISITOR_H

/* Implements the <GtNodeVisitor> interface. */
typedef struct GtExtractFeatureVisitor GtExtractFeatureVisitor;

#include <stdbool.h>
#include "extended/node_visitor.h"
#include "extended/region_mapping_api.h"

const GtNodeVisitorClass* gt_extract_feature_visitor_class(void);
/* takes ownership of <rm> */
GtNodeVisitor*            gt_extract_feature_visitor_new(GtRegionMapping *rm,
                                                         const char*,
                                                         bool join,
                                                         bool translate,
                                                         bool seqid,
                                                         bool target,
                                                         unsigned long width,
                                                         GtFile *outfp);

#endif

==> genometools_1.5.3.orig.tar.gz: genometools-1.5.3/src/extended/extract_feature_visitor.h <==
/*
  Copyright (c) 2006-2011 Gordon Gremme <gordon@gremme.org>
  Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef EXTRACT_FEATURE_VISITOR_H
#define EXTRACT_FEATURE_VISITOR_H

/* Implements the <GtNodeVisitor> interface. */
typedef struct GtExtractFeatureVisitor GtExtractFeatureVisitor;

#include <stdbool.h>
#include "extended/node_visitor.h"
#include "extended/region_mapping_api.h"

const GtNodeVisitorClass* gt_extract_feature_visitor_class(void);
/* takes ownership of <rm> */
GtNodeVisitor*            gt_extract_feature_visitor_new(GtRegionMapping *rm,
                                                         const char*,
                                                         bool join,
                                                         bool translate,
                                                         bool seqid,
                                                         bool target,
                                                         GtUword width,
                                                         GtFile *outfp);

void                      gt_extract_feature_visitor_retain_id_attributes(
                                                GtExtractFeatureVisitor *efv);

#endif
